/* ESP32_pwm_ledfade2
 *  
 * LED vezérlése egy PWM csatorna felhasználásával.
 * A kitöltést periodikusan és Gauss függvény szerint változtatjuk 
 * 
 * Hardver: 
 * ESP32-WROOM-32 Devkit-V1 kártya 
 * Egy LED anódja a GPIO19 kiementre kötve (egy 220 ohmos
 * áramkollátozó ellenálláson keresztül), katódja pedig a 
 * GND-re kötve.
 * 
 * A programhoz felhasznált cikk és mintaprogram: 
 * Joshua Hrisko: Arduino Breathing LED Functions
 * https://makersportal.com/blog/2020/3/27/simple-breathing-led-in-arduino 
 * 
 * Arduino 1.8.15 és ESP32 2.0.0 kiadással tesztelve
 */
#define LED_GPIO   19
#define PWM1_Ch    0
#define PWM1_Res   12
#define PWM1_Freq  1000
 
float smoothness_pts = 500;     // larger=slower change in brightness  
float gamma_par = 0.14;         // affects the width of peak (more or less darkness)
float beta_par = 0.5;           // shifts the gaussian to be symmetric

void setup() {
  ledcAttachPin(LED_GPIO, PWM1_Ch);
  ledcSetup(PWM1_Ch, PWM1_Freq, PWM1_Res);
}
 
void loop() {
  for (int i=0; i<smoothness_pts; i++){
    float pwm_val = 4095.0*(exp(-(pow(((i/smoothness_pts)-beta_par)/gamma_par,2.0))/2.0));
    ledcWrite(PWM1_Ch, int(pwm_val));
    delay(5);
  }
}
